contexttools.TimeSignatureMark
==============================

.. abjad-lineage:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark

.. autoclass:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.attach
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.denominator
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.detach
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.duration
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.effective_context
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.has_non_power_of_two_denominator
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.implied_prolation
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.lilypond_format
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.numerator
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.pair
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.partial
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.start_component
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.storage_format
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.target_context
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.with_power_of_two_denominator
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__call__
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__copy__
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__eq__
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__ge__
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__gt__
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__le__
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__lt__
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__ne__
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__nonzero__
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__repr__
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__str__

Bases
-----

- :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

- :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.duration
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.effective_context
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.has_non_power_of_two_denominator
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.implied_prolation
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.pair
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.start_component
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.storage_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.target_context
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.denominator
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.numerator
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.partial
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.attach
   :noindex:

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.detach
   :noindex:

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.with_power_of_two_denominator
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__call__
   :noindex:

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__copy__
   :noindex:

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__ge__
   :noindex:

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__gt__
   :noindex:

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__le__
   :noindex:

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__lt__
   :noindex:

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__nonzero__
   :noindex:

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__repr__
   :noindex:

.. automethod:: abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark.__str__
   :noindex:
